"""
Type annotations for mediapackage service client.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html)

Usage::

    ```python
    import boto3
    from mypy_boto3_mediapackage import MediaPackageClient

    client: MediaPackageClient = boto3.client("mediapackage")
    ```
"""
import sys
from typing import Any, Dict, List, Type, overload

from botocore.client import ClientMeta

from mypy_boto3_mediapackage.literals import Origination
from mypy_boto3_mediapackage.paginator import (
    ListChannelsPaginator,
    ListHarvestJobsPaginator,
    ListOriginEndpointsPaginator,
)
from mypy_boto3_mediapackage.type_defs import (
    AuthorizationTypeDef,
    CmafPackageCreateOrUpdateParametersTypeDef,
    ConfigureLogsResponseTypeDef,
    CreateChannelResponseTypeDef,
    CreateHarvestJobResponseTypeDef,
    CreateOriginEndpointResponseTypeDef,
    DashPackageTypeDef,
    DescribeChannelResponseTypeDef,
    DescribeHarvestJobResponseTypeDef,
    DescribeOriginEndpointResponseTypeDef,
    EgressAccessLogsTypeDef,
    HlsPackageTypeDef,
    IngressAccessLogsTypeDef,
    ListChannelsResponseTypeDef,
    ListHarvestJobsResponseTypeDef,
    ListOriginEndpointsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    MssPackageTypeDef,
    RotateChannelCredentialsResponseTypeDef,
    RotateIngestEndpointCredentialsResponseTypeDef,
    S3DestinationTypeDef,
    UpdateChannelResponseTypeDef,
    UpdateOriginEndpointResponseTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("MediaPackageClient",)


class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str

    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str


class Exceptions:
    ClientError: Type[BotocoreClientError]
    ForbiddenException: Type[BotocoreClientError]
    InternalServerErrorException: Type[BotocoreClientError]
    NotFoundException: Type[BotocoreClientError]
    ServiceUnavailableException: Type[BotocoreClientError]
    TooManyRequestsException: Type[BotocoreClientError]
    UnprocessableEntityException: Type[BotocoreClientError]


class MediaPackageClient:
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client)
    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html)
    """

    meta: ClientMeta
    exceptions: Exceptions

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.can_paginate)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#can-paginate)
        """

    def configure_logs(
        self,
        Id: str,
        EgressAccessLogs: "EgressAccessLogsTypeDef" = None,
        IngressAccessLogs: "IngressAccessLogsTypeDef" = None,
    ) -> ConfigureLogsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.configure_logs)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#configure-logs)
        """

    def create_channel(
        self, Id: str, Description: str = None, Tags: Dict[str, str] = None
    ) -> CreateChannelResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.create_channel)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#create-channel)
        """

    def create_harvest_job(
        self,
        EndTime: str,
        Id: str,
        OriginEndpointId: str,
        S3Destination: "S3DestinationTypeDef",
        StartTime: str,
    ) -> CreateHarvestJobResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.create_harvest_job)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#create-harvest-job)
        """

    def create_origin_endpoint(
        self,
        ChannelId: str,
        Id: str,
        Authorization: "AuthorizationTypeDef" = None,
        CmafPackage: CmafPackageCreateOrUpdateParametersTypeDef = None,
        DashPackage: "DashPackageTypeDef" = None,
        Description: str = None,
        HlsPackage: "HlsPackageTypeDef" = None,
        ManifestName: str = None,
        MssPackage: "MssPackageTypeDef" = None,
        Origination: Origination = None,
        StartoverWindowSeconds: int = None,
        Tags: Dict[str, str] = None,
        TimeDelaySeconds: int = None,
        Whitelist: List[str] = None,
    ) -> CreateOriginEndpointResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.create_origin_endpoint)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#create-origin-endpoint)
        """

    def delete_channel(self, Id: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.delete_channel)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#delete-channel)
        """

    def delete_origin_endpoint(self, Id: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.delete_origin_endpoint)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#delete-origin-endpoint)
        """

    def describe_channel(self, Id: str) -> DescribeChannelResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.describe_channel)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#describe-channel)
        """

    def describe_harvest_job(self, Id: str) -> DescribeHarvestJobResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.describe_harvest_job)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#describe-harvest-job)
        """

    def describe_origin_endpoint(self, Id: str) -> DescribeOriginEndpointResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.describe_origin_endpoint)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#describe-origin-endpoint)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.generate_presigned_url)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#generate-presigned-url)
        """

    def list_channels(
        self, MaxResults: int = None, NextToken: str = None
    ) -> ListChannelsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.list_channels)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#list-channels)
        """

    def list_harvest_jobs(
        self,
        IncludeChannelId: str = None,
        IncludeStatus: str = None,
        MaxResults: int = None,
        NextToken: str = None,
    ) -> ListHarvestJobsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.list_harvest_jobs)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#list-harvest-jobs)
        """

    def list_origin_endpoints(
        self, ChannelId: str = None, MaxResults: int = None, NextToken: str = None
    ) -> ListOriginEndpointsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.list_origin_endpoints)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#list-origin-endpoints)
        """

    def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.list_tags_for_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#list-tags-for-resource)
        """

    def rotate_channel_credentials(self, Id: str) -> RotateChannelCredentialsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.rotate_channel_credentials)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#rotate-channel-credentials)
        """

    def rotate_ingest_endpoint_credentials(
        self, Id: str, IngestEndpointId: str
    ) -> RotateIngestEndpointCredentialsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.rotate_ingest_endpoint_credentials)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#rotate-ingest-endpoint-credentials)
        """

    def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.tag_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#tag-resource)
        """

    def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.untag_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#untag-resource)
        """

    def update_channel(self, Id: str, Description: str = None) -> UpdateChannelResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.update_channel)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#update-channel)
        """

    def update_origin_endpoint(
        self,
        Id: str,
        Authorization: "AuthorizationTypeDef" = None,
        CmafPackage: CmafPackageCreateOrUpdateParametersTypeDef = None,
        DashPackage: "DashPackageTypeDef" = None,
        Description: str = None,
        HlsPackage: "HlsPackageTypeDef" = None,
        ManifestName: str = None,
        MssPackage: "MssPackageTypeDef" = None,
        Origination: Origination = None,
        StartoverWindowSeconds: int = None,
        TimeDelaySeconds: int = None,
        Whitelist: List[str] = None,
    ) -> UpdateOriginEndpointResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Client.update_origin_endpoint)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/client.html#update-origin-endpoint)
        """

    @overload
    def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/paginators.html#listchannelspaginator)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_harvest_jobs"]
    ) -> ListHarvestJobsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/paginators.html#listharvestjobspaginator)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_origin_endpoints"]
    ) -> ListOriginEndpointsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/paginators.html#listoriginendpointspaginator)
        """



"""
Type annotations for mediapackage service type definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/type_defs.html)

Usage::

    ```python
    from mypy_boto3_mediapackage.type_defs import AuthorizationTypeDef

    data: AuthorizationTypeDef = {...}
    ```
"""
import sys
from typing import Dict, List

from mypy_boto3_mediapackage.literals import (
    AdMarkers,
    AdsOnDeliveryRestrictions,
    EncryptionMethod,
    ManifestLayout,
    Origination,
    PlaylistType,
    Profile,
    SegmentTemplateFormat,
    Status,
    StreamOrder,
    UtcTiming,
    __AdTriggersElement,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "AuthorizationTypeDef",
    "ChannelTypeDef",
    "CmafEncryptionTypeDef",
    "CmafPackageCreateOrUpdateParametersTypeDef",
    "CmafPackageTypeDef",
    "ConfigureLogsResponseTypeDef",
    "CreateChannelResponseTypeDef",
    "CreateHarvestJobResponseTypeDef",
    "CreateOriginEndpointResponseTypeDef",
    "DashEncryptionTypeDef",
    "DashPackageTypeDef",
    "DescribeChannelResponseTypeDef",
    "DescribeHarvestJobResponseTypeDef",
    "DescribeOriginEndpointResponseTypeDef",
    "EgressAccessLogsTypeDef",
    "EncryptionContractConfigurationTypeDef",
    "HarvestJobTypeDef",
    "HlsEncryptionTypeDef",
    "HlsIngestTypeDef",
    "HlsManifestCreateOrUpdateParametersTypeDef",
    "HlsManifestTypeDef",
    "HlsPackageTypeDef",
    "IngestEndpointTypeDef",
    "IngressAccessLogsTypeDef",
    "ListChannelsResponseTypeDef",
    "ListHarvestJobsResponseTypeDef",
    "ListOriginEndpointsResponseTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "MssEncryptionTypeDef",
    "MssPackageTypeDef",
    "OriginEndpointTypeDef",
    "PaginatorConfigTypeDef",
    "RotateChannelCredentialsResponseTypeDef",
    "RotateIngestEndpointCredentialsResponseTypeDef",
    "S3DestinationTypeDef",
    "SpekeKeyProviderTypeDef",
    "StreamSelectionTypeDef",
    "UpdateChannelResponseTypeDef",
    "UpdateOriginEndpointResponseTypeDef",
)

class AuthorizationTypeDef(TypedDict):
    CdnIdentifierSecret: str
    SecretsRoleArn: str

class ChannelTypeDef(TypedDict, total=False):
    Arn: str
    Description: str
    EgressAccessLogs: "EgressAccessLogsTypeDef"
    HlsIngest: "HlsIngestTypeDef"
    Id: str
    IngressAccessLogs: "IngressAccessLogsTypeDef"
    Tags: Dict[str, str]

class _RequiredCmafEncryptionTypeDef(TypedDict):
    SpekeKeyProvider: "SpekeKeyProviderTypeDef"

class CmafEncryptionTypeDef(_RequiredCmafEncryptionTypeDef, total=False):
    ConstantInitializationVector: str
    KeyRotationIntervalSeconds: int

class CmafPackageCreateOrUpdateParametersTypeDef(TypedDict, total=False):
    Encryption: "CmafEncryptionTypeDef"
    HlsManifests: List["HlsManifestCreateOrUpdateParametersTypeDef"]
    SegmentDurationSeconds: int
    SegmentPrefix: str
    StreamSelection: "StreamSelectionTypeDef"

class CmafPackageTypeDef(TypedDict, total=False):
    Encryption: "CmafEncryptionTypeDef"
    HlsManifests: List["HlsManifestTypeDef"]
    SegmentDurationSeconds: int
    SegmentPrefix: str
    StreamSelection: "StreamSelectionTypeDef"

class ConfigureLogsResponseTypeDef(TypedDict, total=False):
    Arn: str
    Description: str
    EgressAccessLogs: "EgressAccessLogsTypeDef"
    HlsIngest: "HlsIngestTypeDef"
    Id: str
    IngressAccessLogs: "IngressAccessLogsTypeDef"
    Tags: Dict[str, str]

class CreateChannelResponseTypeDef(TypedDict, total=False):
    Arn: str
    Description: str
    EgressAccessLogs: "EgressAccessLogsTypeDef"
    HlsIngest: "HlsIngestTypeDef"
    Id: str
    IngressAccessLogs: "IngressAccessLogsTypeDef"
    Tags: Dict[str, str]

class CreateHarvestJobResponseTypeDef(TypedDict, total=False):
    Arn: str
    ChannelId: str
    CreatedAt: str
    EndTime: str
    Id: str
    OriginEndpointId: str
    S3Destination: "S3DestinationTypeDef"
    StartTime: str
    Status: Status

class CreateOriginEndpointResponseTypeDef(TypedDict, total=False):
    Arn: str
    Authorization: "AuthorizationTypeDef"
    ChannelId: str
    CmafPackage: "CmafPackageTypeDef"
    DashPackage: "DashPackageTypeDef"
    Description: str
    HlsPackage: "HlsPackageTypeDef"
    Id: str
    ManifestName: str
    MssPackage: "MssPackageTypeDef"
    Origination: Origination
    StartoverWindowSeconds: int
    Tags: Dict[str, str]
    TimeDelaySeconds: int
    Url: str
    Whitelist: List[str]

class _RequiredDashEncryptionTypeDef(TypedDict):
    SpekeKeyProvider: "SpekeKeyProviderTypeDef"

class DashEncryptionTypeDef(_RequiredDashEncryptionTypeDef, total=False):
    KeyRotationIntervalSeconds: int

class DashPackageTypeDef(TypedDict, total=False):
    AdTriggers: List[__AdTriggersElement]
    AdsOnDeliveryRestrictions: AdsOnDeliveryRestrictions
    Encryption: "DashEncryptionTypeDef"
    ManifestLayout: ManifestLayout
    ManifestWindowSeconds: int
    MinBufferTimeSeconds: int
    MinUpdatePeriodSeconds: int
    PeriodTriggers: List[Literal["ADS"]]
    Profile: Profile
    SegmentDurationSeconds: int
    SegmentTemplateFormat: SegmentTemplateFormat
    StreamSelection: "StreamSelectionTypeDef"
    SuggestedPresentationDelaySeconds: int
    UtcTiming: UtcTiming
    UtcTimingUri: str

class DescribeChannelResponseTypeDef(TypedDict, total=False):
    Arn: str
    Description: str
    EgressAccessLogs: "EgressAccessLogsTypeDef"
    HlsIngest: "HlsIngestTypeDef"
    Id: str
    IngressAccessLogs: "IngressAccessLogsTypeDef"
    Tags: Dict[str, str]

class DescribeHarvestJobResponseTypeDef(TypedDict, total=False):
    Arn: str
    ChannelId: str
    CreatedAt: str
    EndTime: str
    Id: str
    OriginEndpointId: str
    S3Destination: "S3DestinationTypeDef"
    StartTime: str
    Status: Status

class DescribeOriginEndpointResponseTypeDef(TypedDict, total=False):
    Arn: str
    Authorization: "AuthorizationTypeDef"
    ChannelId: str
    CmafPackage: "CmafPackageTypeDef"
    DashPackage: "DashPackageTypeDef"
    Description: str
    HlsPackage: "HlsPackageTypeDef"
    Id: str
    ManifestName: str
    MssPackage: "MssPackageTypeDef"
    Origination: Origination
    StartoverWindowSeconds: int
    Tags: Dict[str, str]
    TimeDelaySeconds: int
    Url: str
    Whitelist: List[str]

class EgressAccessLogsTypeDef(TypedDict, total=False):
    LogGroupName: str

class EncryptionContractConfigurationTypeDef(TypedDict):
    PresetSpeke20Audio: Literal["PRESET-AUDIO-1"]
    PresetSpeke20Video: Literal["PRESET-VIDEO-1"]

class HarvestJobTypeDef(TypedDict, total=False):
    Arn: str
    ChannelId: str
    CreatedAt: str
    EndTime: str
    Id: str
    OriginEndpointId: str
    S3Destination: "S3DestinationTypeDef"
    StartTime: str
    Status: Status

class _RequiredHlsEncryptionTypeDef(TypedDict):
    SpekeKeyProvider: "SpekeKeyProviderTypeDef"

class HlsEncryptionTypeDef(_RequiredHlsEncryptionTypeDef, total=False):
    ConstantInitializationVector: str
    EncryptionMethod: EncryptionMethod
    KeyRotationIntervalSeconds: int
    RepeatExtXKey: bool

class HlsIngestTypeDef(TypedDict, total=False):
    IngestEndpoints: List["IngestEndpointTypeDef"]

class _RequiredHlsManifestCreateOrUpdateParametersTypeDef(TypedDict):
    Id: str

class HlsManifestCreateOrUpdateParametersTypeDef(
    _RequiredHlsManifestCreateOrUpdateParametersTypeDef, total=False
):
    AdMarkers: AdMarkers
    AdTriggers: List[__AdTriggersElement]
    AdsOnDeliveryRestrictions: AdsOnDeliveryRestrictions
    IncludeIframeOnlyStream: bool
    ManifestName: str
    PlaylistType: PlaylistType
    PlaylistWindowSeconds: int
    ProgramDateTimeIntervalSeconds: int

class _RequiredHlsManifestTypeDef(TypedDict):
    Id: str

class HlsManifestTypeDef(_RequiredHlsManifestTypeDef, total=False):
    AdMarkers: AdMarkers
    IncludeIframeOnlyStream: bool
    ManifestName: str
    PlaylistType: PlaylistType
    PlaylistWindowSeconds: int
    ProgramDateTimeIntervalSeconds: int
    Url: str

class HlsPackageTypeDef(TypedDict, total=False):
    AdMarkers: AdMarkers
    AdTriggers: List[__AdTriggersElement]
    AdsOnDeliveryRestrictions: AdsOnDeliveryRestrictions
    Encryption: "HlsEncryptionTypeDef"
    IncludeIframeOnlyStream: bool
    PlaylistType: PlaylistType
    PlaylistWindowSeconds: int
    ProgramDateTimeIntervalSeconds: int
    SegmentDurationSeconds: int
    StreamSelection: "StreamSelectionTypeDef"
    UseAudioRenditionGroup: bool

class IngestEndpointTypeDef(TypedDict, total=False):
    Id: str
    Password: str
    Url: str
    Username: str

class IngressAccessLogsTypeDef(TypedDict, total=False):
    LogGroupName: str

class ListChannelsResponseTypeDef(TypedDict, total=False):
    Channels: List["ChannelTypeDef"]
    NextToken: str

class ListHarvestJobsResponseTypeDef(TypedDict, total=False):
    HarvestJobs: List["HarvestJobTypeDef"]
    NextToken: str

class ListOriginEndpointsResponseTypeDef(TypedDict, total=False):
    NextToken: str
    OriginEndpoints: List["OriginEndpointTypeDef"]

class ListTagsForResourceResponseTypeDef(TypedDict, total=False):
    Tags: Dict[str, str]

class MssEncryptionTypeDef(TypedDict):
    SpekeKeyProvider: "SpekeKeyProviderTypeDef"

class MssPackageTypeDef(TypedDict, total=False):
    Encryption: "MssEncryptionTypeDef"
    ManifestWindowSeconds: int
    SegmentDurationSeconds: int
    StreamSelection: "StreamSelectionTypeDef"

class OriginEndpointTypeDef(TypedDict, total=False):
    Arn: str
    Authorization: "AuthorizationTypeDef"
    ChannelId: str
    CmafPackage: "CmafPackageTypeDef"
    DashPackage: "DashPackageTypeDef"
    Description: str
    HlsPackage: "HlsPackageTypeDef"
    Id: str
    ManifestName: str
    MssPackage: "MssPackageTypeDef"
    Origination: Origination
    StartoverWindowSeconds: int
    Tags: Dict[str, str]
    TimeDelaySeconds: int
    Url: str
    Whitelist: List[str]

class PaginatorConfigTypeDef(TypedDict, total=False):
    MaxItems: int
    PageSize: int
    StartingToken: str

class RotateChannelCredentialsResponseTypeDef(TypedDict, total=False):
    Arn: str
    Description: str
    EgressAccessLogs: "EgressAccessLogsTypeDef"
    HlsIngest: "HlsIngestTypeDef"
    Id: str
    IngressAccessLogs: "IngressAccessLogsTypeDef"
    Tags: Dict[str, str]

class RotateIngestEndpointCredentialsResponseTypeDef(TypedDict, total=False):
    Arn: str
    Description: str
    EgressAccessLogs: "EgressAccessLogsTypeDef"
    HlsIngest: "HlsIngestTypeDef"
    Id: str
    IngressAccessLogs: "IngressAccessLogsTypeDef"
    Tags: Dict[str, str]

class S3DestinationTypeDef(TypedDict):
    BucketName: str
    ManifestKey: str
    RoleArn: str

class _RequiredSpekeKeyProviderTypeDef(TypedDict):
    ResourceId: str
    RoleArn: str
    SystemIds: List[str]
    Url: str

class SpekeKeyProviderTypeDef(_RequiredSpekeKeyProviderTypeDef, total=False):
    CertificateArn: str
    EncryptionContractConfiguration: "EncryptionContractConfigurationTypeDef"

class StreamSelectionTypeDef(TypedDict, total=False):
    MaxVideoBitsPerSecond: int
    MinVideoBitsPerSecond: int
    StreamOrder: StreamOrder

class UpdateChannelResponseTypeDef(TypedDict, total=False):
    Arn: str
    Description: str
    EgressAccessLogs: "EgressAccessLogsTypeDef"
    HlsIngest: "HlsIngestTypeDef"
    Id: str
    IngressAccessLogs: "IngressAccessLogsTypeDef"
    Tags: Dict[str, str]

class UpdateOriginEndpointResponseTypeDef(TypedDict, total=False):
    Arn: str
    Authorization: "AuthorizationTypeDef"
    ChannelId: str
    CmafPackage: "CmafPackageTypeDef"
    DashPackage: "DashPackageTypeDef"
    Description: str
    HlsPackage: "HlsPackageTypeDef"
    Id: str
    ManifestName: str
    MssPackage: "MssPackageTypeDef"
    Origination: Origination
    StartoverWindowSeconds: int
    Tags: Dict[str, str]
    TimeDelaySeconds: int
    Url: str
    Whitelist: List[str]



"""
Type annotations for mediapackage service literal definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediapackage/literals.html)

Usage::

    ```python
    from mypy_boto3_mediapackage.literals import AdMarkers

    data: AdMarkers = "DATERANGE"
    ```
"""
import sys

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = (
    "AdMarkers",
    "AdsOnDeliveryRestrictions",
    "EncryptionMethod",
    "ListChannelsPaginatorName",
    "ListHarvestJobsPaginatorName",
    "ListOriginEndpointsPaginatorName",
    "ManifestLayout",
    "Origination",
    "PlaylistType",
    "PresetSpeke20Audio",
    "PresetSpeke20Video",
    "Profile",
    "SegmentTemplateFormat",
    "Status",
    "StreamOrder",
    "UtcTiming",
    "__AdTriggersElement",
    "__PeriodTriggersElement",
)

AdMarkers = Literal["DATERANGE", "NONE", "PASSTHROUGH", "SCTE35_ENHANCED"]
AdsOnDeliveryRestrictions = Literal["BOTH", "NONE", "RESTRICTED", "UNRESTRICTED"]
EncryptionMethod = Literal["AES_128", "SAMPLE_AES"]
ListChannelsPaginatorName = Literal["list_channels"]
ListHarvestJobsPaginatorName = Literal["list_harvest_jobs"]
ListOriginEndpointsPaginatorName = Literal["list_origin_endpoints"]
ManifestLayout = Literal["COMPACT", "FULL"]
Origination = Literal["ALLOW", "DENY"]
PlaylistType = Literal["EVENT", "NONE", "VOD"]
PresetSpeke20Audio = Literal["PRESET-AUDIO-1"]
PresetSpeke20Video = Literal["PRESET-VIDEO-1"]
Profile = Literal["HBBTV_1_5", "NONE"]
SegmentTemplateFormat = Literal[
    "NUMBER_WITH_DURATION", "NUMBER_WITH_TIMELINE", "TIME_WITH_TIMELINE"
]
Status = Literal["FAILED", "IN_PROGRESS", "SUCCEEDED"]
StreamOrder = Literal["ORIGINAL", "VIDEO_BITRATE_ASCENDING", "VIDEO_BITRATE_DESCENDING"]
UtcTiming = Literal["HTTP-HEAD", "HTTP-ISO", "NONE"]
__AdTriggersElement = Literal[
    "BREAK",
    "DISTRIBUTOR_ADVERTISEMENT",
    "DISTRIBUTOR_OVERLAY_PLACEMENT_OPPORTUNITY",
    "DISTRIBUTOR_PLACEMENT_OPPORTUNITY",
    "PROVIDER_ADVERTISEMENT",
    "PROVIDER_OVERLAY_PLACEMENT_OPPORTUNITY",
    "PROVIDER_PLACEMENT_OPPORTUNITY",
    "SPLICE_INSERT",
]
__PeriodTriggersElement = Literal["ADS"]
